# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^$', views.home, name='lingo-manager-pricing-home'),
    url(r'^import/$', views.config_import, name='lingo-manager-pricing-config-import'),
    url(r'^export/$', views.config_export, name='lingo-manager-pricing-config-export'),
    url(r'^models/$', views.pricing_list, name='lingo-manager-pricing-list'),
    url(
        r'^model/add/$',
        views.pricing_add,
        name='lingo-manager-pricing-add',
    ),
    url(
        r'^model/(?P<pk>\d+)/$',
        views.pricing_detail,
        name='lingo-manager-pricing-detail',
    ),
    url(
        r'^model/(?P<pk>\d+)/edit/$',
        views.pricing_edit,
        name='lingo-manager-pricing-edit',
    ),
    url(
        r'^model/(?P<pk>\d+)/delete/$',
        views.pricing_delete,
        name='lingo-manager-pricing-delete',
    ),
    url(
        r'^model/(?P<pk>\d+)/duplicate/$',
        views.pricing_duplicate,
        name='lingo-manager-pricing-duplicate',
    ),
    url(
        r'^model/(?P<pk>\d+)/export/$',
        views.pricing_export,
        name='lingo-manager-pricing-export',
    ),
    url(
        r'^model/(?P<pk>\d+)/variable/$',
        views.pricing_variable_edit,
        name='lingo-manager-pricing-variable-edit',
    ),
    url(
        r'^model/(?P<pk>\d+)/category/add/$',
        views.pricing_criteria_category_add,
        name='lingo-manager-pricing-criteria-category-add',
    ),
    url(
        r'^model/(?P<pk>\d+)/category/(?P<category_pk>\d+)/edit/$',
        views.pricing_criteria_category_edit,
        name='lingo-manager-pricing-criteria-category-edit',
    ),
    url(
        r'^model/(?P<pk>\d+)/category/(?P<category_pk>\d+)/delete/$',
        views.pricing_criteria_category_delete,
        name='lingo-manager-pricing-criteria-category-delete',
    ),
    url(
        r'^model/(?P<pk>\d+)/order/$',
        views.pricing_criteria_category_order,
        name='lingo-manager-pricing-criteria-category-order',
    ),
    url(
        r'^criterias/$',
        views.criteria_list,
        name='lingo-manager-pricing-criteria-list',
    ),
    url(
        r'^criteria/category/add/$',
        views.criteria_category_add,
        name='lingo-manager-pricing-criteria-category-add',
    ),
    url(
        r'^criteria/category/(?P<pk>\d+)/edit/$',
        views.criteria_category_edit,
        name='lingo-manager-pricing-criteria-category-edit',
    ),
    url(
        r'^criteria/category/(?P<pk>\d+)/delete/$',
        views.criteria_category_delete,
        name='lingo-manager-pricing-criteria-category-delete',
    ),
    url(
        r'^criteria/category/(?P<pk>\d+)/export/$',
        views.criteria_category_export,
        name='lingo-manager-pricing-criteria-category-export',
    ),
    url(
        r'^criteria/category/(?P<pk>\d+)/order/$',
        views.criteria_order,
        name='lingo-manager-pricing-criteria-order',
    ),
    url(
        r'^criteria/category/(?P<category_pk>\d+)/add/$',
        views.criteria_add,
        name='lingo-manager-pricing-criteria-add',
    ),
    url(
        r'^criteria/category/(?P<category_pk>\d+)/(?P<pk>\d+)/edit/$',
        views.criteria_edit,
        name='lingo-manager-pricing-criteria-edit',
    ),
    url(
        r'^criteria/category/(?P<category_pk>\d+)/(?P<pk>\d+)/delete/$',
        views.criteria_delete,
        name='lingo-manager-pricing-criteria-delete',
    ),
    url(
        r'^agendas/sync/$',
        views.agenda_sync,
        name='lingo-manager-agenda-sync',
    ),
    url(
        r'^agendas/$',
        views.agenda_list,
        name='lingo-manager-agenda-list',
    ),
    url(
        r'^agenda/(?P<pk>\d+)/$',
        views.agenda_detail,
        name='lingo-manager-agenda-detail',
    ),
    url(
        r'^agenda/((?P<slug>[-_a-zA-Z0-9]+))/$',
        views.agenda_detail_redirect,
        name='lingo-manager-agenda-detail-redirect',
    ),
    url(
        r'^agenda/(?P<pk>\d+)/export/$',
        views.agenda_export,
        name='lingo-manager-agenda-export',
    ),
    url(
        r'^agenda/(?P<pk>\d+)/check-options/$',
        views.agenda_booking_check_settings,
        name='lingo-manager-agenda-booking-check-settings',
    ),
    url(
        r'^agenda-pricings/$',
        views.agenda_pricing_list,
        name='lingo-manager-agenda-pricing-list',
    ),
    url(
        r'^agenda-pricing/add/$',
        views.agenda_pricing_add,
        name='lingo-manager-agenda-pricing-add',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/$',
        views.agenda_pricing_detail,
        name='lingo-manager-agenda-pricing-detail',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/edit/$',
        views.agenda_pricing_edit,
        name='lingo-manager-agenda-pricing-edit',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/delete/$',
        views.agenda_pricing_delete,
        name='lingo-manager-agenda-pricing-delete',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/export/$',
        views.agenda_pricing_export,
        name='lingo-manager-agenda-pricing-export',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/test-tool/$',
        views.agenda_pricing_test_tool,
        name='lingo-manager-agenda-pricing-test-tool',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/agenda/add/$',
        views.agenda_pricing_agenda_add,
        name='lingo-manager-agenda-pricing-agenda-add',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/agenda/(?P<agenda_pk>\d+)/delete/$',
        views.agenda_pricing_agenda_delete,
        name='lingo-manager-agenda-pricing-agenda-delete',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/matrix/edit/$',
        views.agenda_pricing_matrix_edit,
        name='lingo-manager-agenda-pricing-matrix-edit',
    ),
    url(
        r'^agenda-pricing/(?P<pk>\d+)/matrix/(?P<slug>[-_a-zA-Z0-9]+)/edit/$',
        views.agenda_pricing_matrix_edit,
        name='lingo-manager-agenda-pricing-matrix-slug-edit',
    ),
    url(r'^check-types/$', views.check_type_list, name='lingo-manager-check-type-list'),
    url(
        r'^check-type/group/add/$',
        views.check_type_group_add,
        name='lingo-manager-check-type-group-add',
    ),
    url(
        r'^check-type/group/(?P<pk>\d+)/edit/$',
        views.check_type_group_edit,
        name='lingo-manager-check-type-group-edit',
    ),
    url(
        r'^check-type/group/(?P<pk>\d+)/delete/$',
        views.check_type_group_delete,
        name='lingo-manager-check-type-group-delete',
    ),
    url(
        r'^check-type/group/(?P<pk>\d+)/export/$',
        views.check_type_group_export,
        name='lingo-manager-check-type-group-export',
    ),
    url(
        r'^check-type/group/(?P<group_pk>\d+)/add/$',
        views.check_type_add,
        name='lingo-manager-check-type-add',
    ),
    url(
        r'^check-type/group/(?P<group_pk>\d+)/(?P<pk>\d+)/edit/$',
        views.check_type_edit,
        name='lingo-manager-check-type-edit',
    ),
    url(
        r'^check-type/group/(?P<group_pk>\d+)/(?P<pk>\d+)/delete/$',
        views.check_type_delete,
        name='lingo-manager-check-type-delete',
    ),
]
